@@ -2,7 +2,7 @@ use crossbeam::channel::{Receiver, Sender, unbounded};
 use futures::Stream;
 use parking_lot::RwLock;
 use sdl2_sys::{SDL_DropEvent, SDL_free};
-use xecs::{entity::EntityId, system::System, world::World};
+use xecs::{EntityId, System, World};
 use std::{ffi::CStr, path::PathBuf, pin::Pin, sync::Arc, task::{Context, Poll, Waker}};
 
 #[derive(Debug, Clone)]
