@@ -2,8 +2,7 @@ use crate::common::{Result, SdlError};
 use crate::window::window::Window;
 use parking_lot::RwLock;
 use sdl2_sys::*;
-use xecs::entity::EntityId;
-use xecs::world::World;
+use xecs::{ EntityId, World};
 use std::ffi::CString;
 use std::fmt::{Debug, Formatter};
 use std::sync::Arc;
